import React, { useState, useEffect, useCallback } from 'react';
import {
  Tree,
  Table,
  Space,
  message,
  Modal,
  Form,
  Input,
  notification,
  Tooltip,
  Row,
  Col,
  Tabs,
  Button,
  Spin,
} from 'antd';
import {
  UsergroupAddOutlined,
  EditTwoTone,
  DeleteTwoTone,
  ShareAltOutlined,
  UnlockOutlined,
  ApartmentOutlined,
  StopOutlined,
  DoubleLeftOutlined,
  DoubleRightOutlined,
} from '@ant-design/icons';
import PageContainer from '@/components/BasePageContainer';
import voca from 'voca';
import zhCN from 'antd/es/locale/zh_CN';
import {
  addToOrg,
  editOrgInfo,
  getOneOUUserListNew,
  getUserByKey,
  getUserRelationList,
  getUserTree,
  addUser as postAddUser,
  deleteUser as postDeleteUser,
  setUserState as postSetUserState,
  editUser as postEditUser,
  submitAddOrg as postAddOrg,
  deleteOrg as postDeleteOrg,
  updateUserPassword,
  setUserRelation,
} from '@/services/userCenter/userManage/api';
import ListCardItem from '../orgnazation/listCardItem';
import styles from './UserManage.less';

const UserManage = () => {
  const [treeLoading, setTreeLoading] = useState(false);
  const [tableLoading, setTableLoading] = useState(false);
  const [loading, setLoading] = useState(true);

  const [treeData, setTreeData] = useState([]); // 用户机构树
  const [expandedKeys, setExpandedKeys] = useState(['']);
  const [treeDataCopy, setTreeDataCopy] = useState([]); // 机构树数据备份，用于更改机构
  const [treeState, setTreeState] = useState(true); // 树第一次加载
  // const [treeDispaly, setTreeDispaly] = useState(''); // 1
  const [treeVisible, setTreeVisible] = useState(true); // 树是否可见
  const [tableData, setTableData] = useState([]); // 用户表
  const [orgFilters, setOrgFilters] = useState([]); // 用户列筛选
  const [searchWord, setSearchWord] = useState(''); // 关键字
  const [currentSelectOrg, setCurrentSelectOrg] = useState([]); // 左侧机构数-选中组织
  const [currentSelectOldOrg, setCurrentSelectOldOrg] = useState([]); // 更改机构时的树-原先选中组织

  /** ***Modal弹框,是否可视**** */
  const [userVisible, setUserVisible] = useState(false); // 添加用户
  const [addOrgVisible, setAddOrgVisible] = useState(false); // 添加机构
  const [editOrgVisible, setEditOrgVisible] = useState(false); // 编辑机构
  const [deleteOrgVisible, setDeleteOrgVisible] = useState(false); // 删除机构
  const [roleVisible, setRoleVisible] = useState(false); // 用户关联
  const [changeOrgVisible, setChangeOrgVisible] = useState(false); // 更改机构
  const [passwordVisible, setPasswordVisible] = useState(false); // 修改密码
  const [editUserVisible, setEditUserVisible] = useState(false); // 编辑用户
  const [freezeUserVisible, setFreezeUserVisible] = useState(false); // 冻结用户
  const [deleteUserVisible, setDeleteUserVisible] = useState(false); // 删除用户

  const [orgTitle, setOrgTitle] = useState('机构'); // 弹框标题
  const [tableLength, setTableLength] = useState(0); // 表格标题
  const [orgID, setOrgID] = useState(); // 机构ID
  const [newOrgID, setNewOrgID] = useState(); // 更改机构新选择的ID
  const [currentUser, setCurrentUser] = useState({}); // 当前用户

  const [rolelist, setRolelist] = useState([]); // 角色列表
  const [stationlist, setStationlist] = useState([]); // 站点列表
  const [roleValueList, setRoleValueList] = useState({}); // 勾选的角色列表
  const [stationValueList, setStationValueList] = useState({}); // 勾选的站点列表

  /** ***表单相关**** */
  const [addUserForm] = Form.useForm(); // 添加用户
  const [addOrgForm] = Form.useForm(); // 添加机构
  const [editOrgForm] = Form.useForm(); // 编辑机构
  const [editUserForm] = Form.useForm(); // 编辑用户
  const [passwordForm] = Form.useForm(); // 修改密码
  const { TabPane } = Tabs;
  const { Search } = Input;

  // 获取搜索框的值
  const handleSearch = e => {
    setSearchWord(e.target.value);
  };

  const getRoleValueCallback = useCallback((value, index) => {
    roleValueList[index] = value;
    setRoleValueList({ ...roleValueList });
  }, []);

  const getStationValueCallback = useCallback((value, index) => {
    stationValueList[index] = value;
    setStationValueList({ ...stationValueList });
  }, []);

  // 用户表列名
  const columns = [
    {
      title: '登录名',
      dataIndex: 'loginName',
      key: 'loginName',
      fixed: 'left',
      width: 100,
      render: item => (
        <div
          ref={r => {
            if (r) {
              r.innerHTML = item;
            }
          }}
        />
      ),
    },
    {
      title: '用户姓名',
      dataIndex: 'userName',
      key: 'userName',
      width: 100,
      render: item => (
        <div
          ref={r => {
            if (r) {
              r.innerHTML = item;
            }
          }}
        />
      ),
    },
    {
      title: '所在机构',
      dataIndex: 'OUName',
      key: 'OUName',
      width: 150,
      filters: orgFilters,
      onFilter: (value, record) => record.OUName === value,
    },
    {
      title: '手机号码',
      dataIndex: 'phone',
      key: 'phone',
      width: 120,
      ellipsis: true,
    },
    {
      title: '钉钉账户',
      dataIndex: 'ddid',
      key: 'ddid',
      width: 100,
    },
    {
      title: '微信账户',
      dataIndex: 'wxid',
      key: 'wxid',
      width: 100,
    },
    {
      title: '操作',
      key: 'action',
      fixed: 'right',
      width: 250,
      align: 'center',
      render: (text, record) => (
        <Space size="middle">
          <Tooltip title="关联角色">
            <ShareAltOutlined
              onClick={() => relateRole(record)}
              style={{ fontSize: '16px', color: '#1890FF' }}
            />
          </Tooltip>
          <Tooltip title="更改机构">
            <ApartmentOutlined
              onClick={() => changeOrg(record)}
              style={{ fontSize: '16px', color: '#1890FF' }}
            />
          </Tooltip>
          <Tooltip title="修改密码">
            <UnlockOutlined
              onClick={() => changePassword(record)}
              style={{ fontSize: '16px', color: '#1890FF' }}
            />
          </Tooltip>
          <Tooltip title="编辑用户">
            <EditTwoTone
              onClick={() => editUser(record)}
              style={{ fontSize: '16px' }}
            />
          </Tooltip>

          {(record.state === '0' || record.state === null) && (
            <>
              <Tooltip title="冻结用户">
                <StopOutlined
                  onClick={() => freezeUser(record)}
                  style={{ fontSize: '16px', color: '#1890FF' }}
                />
              </Tooltip>
            </>
          )}
          {record.state === '1' && (
            <>
              <Tooltip title="解冻用户">
                <StopOutlined
                  onClick={() => freezeUser(record)}
                  style={{ fontSize: '16px' }}
                />
              </Tooltip>
            </>
          )}
          <Tooltip title="删除用户">
            <DeleteTwoTone
              onClick={() => deleteUser(record)}
              style={{ fontSize: '16px' }}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];
  const [selectionType] = useState('checkbox');
  const rowSelection = {
    onChange: (selectedRowKeys, selectedRows) => {
      console.log(
        `selectedRowKeys: ${selectedRowKeys}`,
        'selectedRows: ',
        selectedRows,
      );
    },
    getCheckboxProps: record => ({
      name: record.name,
    }),
  };

  // 渲染机构树
  const mapTree = org => {
    const haveChildren = Array.isArray(org.children) && org.children.length > 0;
    return {
      title: org.text,
      key: org.id,
      // icon: org.leaf ? <FileOutlined /> : <FolderOpenOutlined />,
      // 判断它是否存在子集，若果存在就进行再次进行遍历操作，知道不存在子集便对其他的元素进行操作
      children: haveChildren ? org.children.map(i => mapTree(i)) : [],
    };
  };
  // 重新渲染树
  const updateTrees = () => {
    setTreeLoading(true);
    getUserTree(-1, -1)
      .then(res => {
        if (res.length > 0) {
          setTreeLoading(false);
          setTreeData(res);
          setTreeDataCopy(res);
          // 第一次加载，默认选择第一个组织
          if (treeState) {
            onSelect([res[0].id], false);
            setTreeState(false);
          }
        } else {
          setTreeLoading(false);
          notification.error({
            message: '获取失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTreeLoading(false);
        message.error(err);
      });
  };

  // 获取用户机构树
  useEffect(() => {
    updateTrees();
  }, []);

  // 点击树节点，获取当前机构下所有用户
  const onSelect = (props, e) => {
    console.log(e);
    setTableLoading(true);
    if (e) {
      setOrgTitle(e.node.title);
    }
    if (!props[0]) {
      setCurrentSelectOrg(currentSelectOrg);
    } else {
      setCurrentSelectOrg(props[0]);
    }
    setOrgID(props[0] || currentSelectOrg);
    getOneOUUserListNew(props[0] || currentSelectOrg)
      .then(res => {
        if (res.code === 0) {
          setTableLoading(false);
          setSearchWord(''); // 搜索框置空
          setOrgTitle(res.data.GroupName);
          // 返回用户表数据结构处理，扁平化
          const temp = flatten(getUsers(res.data));
          // 设置过滤字段
          let arr = temp.map(item => item.OUName);
          arr = arr.filter((value, index) => arr.indexOf(value) === index);
          setOrgFilters(arr.map(item => ({ text: item, value: item })));
          console.log(temp);
          setTableLength(temp.length);
          const table = temp.map((item, index) => {
            item.key = index;
            item.phone = item.phone || '-';
            item.ddid = item.ddid ? '已绑定' : '未绑定';
            item.wxid = item.wxid ? '已绑定' : '未绑定';
            return item;
          });
          setTableData(table);
        } else {
          setTableLoading(false);
          notification.error({
            message: '获取失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };

  // 返回用户表数据结构处理，扁平化
  const getUsers = orgObj => {
    let result = orgObj.Users;
    result.map(item => {
      item.OUID = orgObj.GroupId;
      item.OUName = orgObj.GroupName;
      return item;
    });
    if (orgObj.Childs.length > 0)
      result = [...result, ...orgObj.Childs.map(o => getUsers(o))];
    return result;
  };
  const flatten = arr => {
    while (arr.some(item => Array.isArray(item))) {
      arr = [].concat(...arr);
    }
    return arr;
  };

  // 添加用户
  const addUser = () => {
    setUserVisible(true);
  };
  // 在根目录下添加机构
  const addOrg = (title, id) => {
    setAddOrgVisible(true);
    setOrgTitle(title);
    setOrgID(id);
  };
  // 添加下级机构
  const addSubOrg = () => {
    setAddOrgVisible(true);
  };
  // 编辑机构
  const editOrg = () => {
    setEditOrgVisible(true);
    editOrgForm.setFieldsValue({
      OUName: orgTitle,
    });
  };
  // 删除机构
  const deleteOrg = () => {
    setDeleteOrgVisible(true);
    // 删除后默认选择第一个组织
    setTreeState(true);
  };

  // 在currentUser变化后获取角色列表
  useEffect(() => {
    if (currentUser && currentUser.userID) {
      getRoleList();
    }
  }, [currentUser]);

  /** ***右侧表格相关操作****** */
  // 用户关联
  const relateRole = record => {
    setRoleVisible(true);
    setCurrentUser(record);
  };
  // 更改机构
  const changeOrg = record => {
    setChangeOrgVisible(true);
    setCurrentUser(record);
    setCurrentSelectOldOrg(record.OUID);
  };
  // 修改密码
  const changePassword = record => {
    setPasswordVisible(true);
    passwordForm.setFieldsValue({
      oldpassword: record.password,
    });
    setCurrentUser(record);
  };
  // 编辑用户
  const editUser = record => {
    // console.log(record);
    setEditUserVisible(true);
    editUserForm.setFieldsValue({
      loginName: voca.stripTags(record.loginName),
      userName: voca.stripTags(record.userName),
      phone: record.phone || '',
      email: record.email || '',
    });
    setCurrentUser(record);
  };
  // 冻结用户
  const freezeUser = record => {
    setFreezeUserVisible(true);
    setCurrentUser(record);
  };
  // 删除用户
  const deleteUser = record => {
    setDeleteUserVisible(true);
    setCurrentUser(record);
  };

  // 查找用户
  const submitSearchUser = () => {
    getUserByKey(searchWord)
      .then(res => {
        if (res.success) {
          setTableData(res.root);
          setTableLength(res.root.length);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  /** ***表单提交相关操作****** */
  // 提交-添加用户
  const submitAddUser = () => {
    postAddUser({
      OUID: orgID,
      loginName: addUserForm.getFieldValue('loginName'),
      userName: addUserForm.getFieldValue('userName'),
      password: addUserForm.getFieldValue('password'),
      phone: addUserForm.getFieldValue('phone') || '',
      email: addUserForm.getFieldValue('email') || '',
    })
      .then(res => {
        if (res.success) {
          setUserVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取用户表
          onSelect([orgID]);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  // 提交-添加下级机构
  const submitAddOrg = () => {
    postAddOrg(
      orgID,
      addOrgForm.getFieldValue('OUName'),
      addOrgForm.getFieldValue('desrciption') || '',
      '',
    )
      .then(res => {
        if (res.success) {
          setAddOrgVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取机构树与用户表
          updateTrees().then(() => {
            // 只能是字符串，数字没有选择效果
            onSelect([`${res.OUID}`]);
            setExpandedKeys([`${res.OUID}`]);
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };

  // 提交-编辑当前机构
  const submitEditOrg = () =>
    editOrgInfo(
      orgID,
      editOrgForm.getFieldValue('OUName'),
      editOrgForm.getFieldValue('desrciption') || '',
      '',
    )
      .then(res => {
        if (res.success) {
          setEditOrgVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取机构树与用户表
          updateTrees();
          onSelect([orgID]);
          setExpandedKeys([`${orgID}`]);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });

  // 提交-删除机构
  const submitDeleteOrg = () =>
    postDeleteOrg(orgID)
      .then(res => {
        if (res.success) {
          setDeleteOrgVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取机构树与用户表
          updateTrees();
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  // 根据当前 userID 获取用户关联角色
  const getRoleList = () => {
    setLoading(true);
    getUserRelationList(currentUser.userID)
      .then(res => {
        setLoading(false);
        if (res.success) {
          const { roleList, stationList } = res;
          setRolelist(roleList);
          setStationlist(stationList);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setLoading(false);
        setTableLoading(false);
        message.error(err);
      });
  };
  // 提交-关联角色
  const submitRole = () => {
    setUserRelation(
      currentUser.userID,
      Object.keys(roleValueList)
        .map(k => roleValueList[k])
        .flat(),
      Object.keys(stationValueList)
        .map(k => stationValueList[k])
        .flat(),
    )
      .then(res => {
        if (res.success) {
          setRoleVisible(false);
          // 跳转到新组织机构下的用户表
          onSelect([`${currentUser.OUID}`]);
          setExpandedKeys([`${currentUser.OUID}`]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  };
  // 提交-更改机构
  const submitChangeOrg = () =>
    addToOrg(currentUser.userID, currentUser.OUID, newOrgID)
      .then(res => {
        if (res.success) {
          setChangeOrgVisible(false);
          // 跳转到新组织机构下的用户表
          onSelect([newOrgID]);
          setExpandedKeys([`${newOrgID}`]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  // 提交-修改密码
  const submitChangePassword = () =>
    updateUserPassword(
      currentUser.userID,
      passwordForm.getFieldValue('password'),
      passwordForm.getFieldValue('newPassword'),
      passwordForm.getFieldValue('passwordConfirm'),
    )
      .then(res => {
        if (res.success) {
          setPasswordVisible(false);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        message.error(err);
      });
  // 提交-编辑用户
  const submitEditUser = () =>
    postEditUser(
      currentUser.userID,
      editUserForm.getFieldValue('loginName'),
      editUserForm.getFieldValue('userName'),
      editUserForm.getFieldValue('phone') || '',
      editUserForm.getFieldValue('email') || '',
    )
      .then(res => {
        if (res.success) {
          setEditUserVisible(false);
          // 重新获取用户表
          onSelect([`${currentUser.OUID}`]);
          setExpandedKeys([`${currentUser.OUID}`]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  // 提交-冻结用户
  const submitFreezeUser = () => {
    let state = '';
    if (currentUser.state === '0' || currentUser.state === null) {
      state = '1';
    } else {
      state = '0';
    }
    postSetUserState(currentUser.userID, state)
      .then(res => {
        if (res.success) {
          setFreezeUserVisible(false);
          // 重新获取用户表
          onSelect([`${currentUser.OUID}`]);
          setExpandedKeys([`${currentUser.OUID}`]);
          notification.success({
            message: '提交成功',
          });
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };
  const submitDeleteUser = () => {
    postDeleteUser(currentUser.userID)
      .then(res => {
        if (res.success) {
          setDeleteUserVisible(false);
          notification.success({
            message: '提交成功',
          });
          // 重新获取用户表
          onSelect([`${currentUser.OUID}`]);
          setExpandedKeys([`${currentUser.OUID}`]);
        } else {
          notification.error({
            message: '提交失败',
            description: res.message,
          });
        }
      })
      .catch(err => {
        setTableLoading(false);
        message.error(err);
      });
  };

  return (
    <PageContainer className={styles.userManageContainer}>
      <div className={styles.contentContainer}>
        {/* 左侧机构树 */}
        <Spin spinning={treeLoading} tip="loading...">
          <div className={treeVisible ? styles.orgContainer : styles.hide}>
            {/* <div className={styles.orgContainer} style={{ display: treeDispaly }}> */}
            <span style={{ margin: '10px' }}>机构列表</span>
            <Tooltip title="添加机构">
              <UsergroupAddOutlined
                onClick={() => addOrg('根目录', '-1')}
                style={{
                  float: 'right',
                  color: '#1890FF',
                  fontSize: '18px',
                }}
              />
            </Tooltip>
            {treeData.length > 0 && (
              <Tree
                showIcon="true"
                showLine={{ showLeafIcon: false }}
                // blockNode="true"
                autoExpandParent="true"
                expandedKeys={[currentSelectOrg]}
                selectedKeys={[currentSelectOrg]}
                onSelect={onSelect}
                treeData={treeData.map(t => mapTree(t))}
              />
            )}
          </div>
        </Spin>
        <div style={{ color: '#1890FF', marginTop: '35vh', fontSize: '18px' }}>
          {treeVisible && (
            <Tooltip title="隐藏机构列表">
              <DoubleLeftOutlined
                onClick={() => {
                  setTreeVisible(false);
                  // setTreeDispaly('none');
                }}
              />
            </Tooltip>
          )}
          {!treeVisible && (
            <Tooltip title="显示机构列表">
              <DoubleRightOutlined
                onClick={() => {
                  setTreeVisible(true);
                  // setTreeDispaly('block');
                }}
              />
            </Tooltip>
          )}
        </div>

        {/* 右侧用户表 */}
        <div className={styles.userContainer}>
          <div style={{ height: '50px' }}>
            <p style={{ margin: '16px 0 10px 16px', display: 'inline-block' }}>
              用户数量（
              <span className={styles.redText}>{tableLength}</span>）
            </p>
            <span style={{ float: 'right', margin: '10px' }}>
              <Search
                style={{ width: 266 }}
                placeholder="搜索登录名称/用户名称/手机号"
                onSearch={submitSearchUser}
                onChange={e => handleSearch(e)}
                enterButton
                value={searchWord}
              />
              <Button type="primary" onClick={addUser}>
                添加用户
              </Button>
              <Button type="primary" onClick={addSubOrg}>
                添加机构
              </Button>
              <Button type="primary" onClick={editOrg}>
                编辑机构
              </Button>
              <Button type="primary" onClick={deleteOrg}>
                删除机构
              </Button>
            </span>
          </div>
          <Table
            rowSelection={{
              type: selectionType,
              ...rowSelection,
            }}
            size="small"
            rowKey={record => record.userID}
            locale={zhCN}
            bordered
            columns={columns}
            dataSource={tableData}
            loading={tableLoading}
            scroll={{ x: 'max-content' }}
            pagination={{
              showTotal: () => `共${tableLength}条`,
              pageSizeOptions: [10, 20, 50, 100],
              showQuickJumper: true,
              showSizeChanger: true,
            }}
          />
        </div>

        {/* Modal弹框 */}

        {/* 添加用户 */}
        <Modal
          title={`在${orgTitle}下添加用户`}
          visible={userVisible}
          onOk={submitAddUser}
          onCancel={() => setUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={addUserForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="loginName"
              label="登录名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入登录名称" />
            </Form.Item>
            <Form.Item
              name="password"
              label="账户密码"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入账户密码" />
            </Form.Item>
            <Form.Item
              name="userName"
              label="用户名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入用户姓名" />
            </Form.Item>
            <Form.Item name="phone" label="手机号码">
              <Input placeholder="请输入手机号码" />
            </Form.Item>
            <Form.Item name="email" label="电子邮箱">
              <Input placeholder="请输入电子邮箱" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 添加下级机构 */}
        <Modal
          title={`在${orgTitle}下添加机构`}
          visible={addOrgVisible}
          onOk={submitAddOrg}
          onCancel={() => setAddOrgVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={addOrgForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="OUName"
              label="机构名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入机构名称" />
            </Form.Item>
            <Form.Item name="description" label="描述">
              <Input placeholder="请输入相关描述" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 编辑机构 */}
        <Modal
          title={`编辑${orgTitle}`}
          visible={editOrgVisible}
          onOk={submitEditOrg}
          onCancel={() => setEditOrgVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={editOrgForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="OUName"
              label="机构名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入机构名称" />
            </Form.Item>
            <Form.Item name="description" label="描述">
              <Input placeholder="请输入相关描述" />
            </Form.Item>
          </Form>
        </Modal>
        <Modal
          title="确认删除机构"
          visible={deleteOrgVisible}
          onOk={submitDeleteOrg}
          onCancel={() => setDeleteOrgVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <p>即将删除该机构，是否确认删除？</p>
        </Modal>
        {/* 用户关联 */}
        <Modal
          title="用户关联"
          visible={roleVisible}
          onOk={submitRole}
          onCancel={() => setRoleVisible(false)}
          okText="确认"
          cancelText="取消"
          width="960px"
        >
          <Spin spinning={loading} tip="loading">
            <Tabs defaultActiveKey="1">
              <TabPane tab="角色" key="1">
                {roleVisible &&
                  rolelist.map((role, index) => (
                    <ListCardItem
                      itemid={index}
                      key={`item${index}key`}
                      userList={role.roleList}
                      OUName={role.visibleTitle}
                      getValueCallback={getRoleValueCallback}
                    />
                  ))}
              </TabPane>
              <TabPane tab="站点" key="2">
                {roleVisible &&
                  stationlist.map((station, index) => (
                    <ListCardItem
                      itemid={index}
                      key={`item${index}key`}
                      userList={station.stationList}
                      OUName={station.visibleTitle}
                      getValueCallback={getStationValueCallback}
                    />
                  ))}
              </TabPane>
            </Tabs>
          </Spin>
        </Modal>
        {/* 更改机构 */}
        <Modal
          title="更改机构"
          visible={changeOrgVisible}
          onOk={submitChangeOrg}
          onCancel={() => setChangeOrgVisible(false)}
          okText="确认"
          cancelText="取消"
          width="330px"
        >
          <span>请选择要更改的目标机构：</span>
          {changeOrgVisible && treeDataCopy.length > 0 && (
            <Tree
              showIcon="true"
              showLine={{ showLeafIcon: false }}
              defaultExpandAll="true"
              // 未切换时原先的节点，注意要转字符串
              selectedKeys={[`${currentSelectOldOrg}`]}
              onSelect={value => {
                setNewOrgID(value[0]);
                // 切换后选中的节点
                setCurrentSelectOldOrg(value[0]);
              }}
              treeData={treeDataCopy.map(t => mapTree(t))}
            />
          )}
        </Modal>
        {/* 修改密码 */}
        <Modal
          title="修改密码"
          visible={passwordVisible}
          onOk={submitChangePassword}
          onCancel={() => setPasswordVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={passwordForm} labelCol={{ span: 4 }}>
            <Form.Item name="oldpassword" label="原始密码">
              <Input disabled />
            </Form.Item>
            <Form.Item
              name="newPassword"
              label="新密码"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入新密码" />
            </Form.Item>
            <Form.Item
              name="passwordConfirm"
              label="确认密码"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="再次确认新密码" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 编辑用户 */}
        <Modal
          title="编辑用户"
          visible={editUserVisible}
          onOk={submitEditUser}
          onCancel={() => setEditUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <Form form={editUserForm} labelCol={{ span: 4 }}>
            <Form.Item
              name="loginName"
              label="登录名称"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入登录名称" />
            </Form.Item>
            <Form.Item
              name="userName"
              label="用户姓名"
              rules={[{ required: true, message: '不能为空' }]}
            >
              <Input placeholder="请输入用户姓名" />
            </Form.Item>
            <Form.Item name="phone" label="手机号码">
              <Input placeholder="请输入手机号码" />
            </Form.Item>
            <Form.Item name="email" label="电子邮箱">
              <Input placeholder="请输入电子邮箱" />
            </Form.Item>
          </Form>
        </Modal>
        {/* 冻结用户 */}
        <Modal
          title="请确认"
          visible={freezeUserVisible}
          onOk={submitFreezeUser}
          onCancel={() => setFreezeUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <p>
            即将{+currentUser.state ? '激活' : '冻结'}用户{' '}
            <span className={styles.redText}>{currentUser.loginName}</span>
            ，是否确认
            {+currentUser.state ? '激活' : '冻结'}？
          </p>
        </Modal>
        {/* 删除用户 */}
        <Modal
          title="确认删除用户"
          visible={deleteUserVisible}
          onOk={submitDeleteUser}
          onCancel={() => setDeleteUserVisible(false)}
          okText="确认"
          cancelText="取消"
        >
          <p>
            将删除用户
            <span className={styles.redText}>
              {voca.stripTags(currentUser.loginName)}
            </span>
            , 是否确认删除？
          </p>
        </Modal>
      </div>
    </PageContainer>
  );
};

export default UserManage;
